local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

plugins = {
  {
    'maxmx03/dracula.nvim',
    lazy = false,
    config = function ()
      local dracula = require 'dracula'
      dracula.setup()
      vim.cmd.colorscheme 'dracula'
    end
  },
  {
    'nvimdev/dashboard-nvim',
    event = 'VimEnter',
    config = function ()
      require('dashboard').setup{
        theme = "hyper"
      }
    end,
    dependencies = {{'nvim-tree/nvim-web-devicons'}}
  },
  {
    'romgrk/barbar.nvim',
    init = function() 
      vim.g.barbar_autosetup = false
      require('barbar').setup {
        auto_hide = 1
      }
    end,
    dependencies = {
      'lewis6991/gitsigns.nvim',
      'nvim-tree/nvim-web-devicons',
    },
  },
  {
    'NTBBloodbath/galaxyline.nvim',
    config = function() require('galaxyline.themes.eviline') end,
    dependencies = {{'nvim-tree/nvim-web-devicons'}},
  },
  {
    "nvim-treesitter/nvim-treesitter",
    build = ":TSUpdate",
    config = function () 
      local configs = require("nvim-treesitter.configs")
      configs.setup({
	ensure_installed = { "c", "rust", "lua", "vim", "vimdoc", "javascript", "html", "astro" },
	sync_install = false,
	highlight = { enable = true },
	indent = { enable = true },  
      })
    end
  },
}

require("lazy").setup(plugins)

vim.opt.smarttab = true
vim.opt.expandtab = true
vim.opt.shiftwidth = 2
vim.opt.guifont = "victor mono:h12"
